# WatchResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**expiration** | **str** | When Gmail will stop sending notifications for mailbox updates (epoch millis). Call &#x60;watch&#x60; again before this time to renew the watch. | [optional] 
**history_id** | **str** | The ID of the mailbox&#x27;s current history record. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

